| bibstyle_JSSextra | R Documentation |
Get or create bibstyle JSSextra or clones of it for derived bib styles.
bibstyle_JSSextra(style = "JSSextra", reset = FALSE, make_default = FALSE)
style |
the name of the style. The default is |
reset |
if |
make_default |
if |
bibstyle_JSSextra() returns the bib style "JSSextra"
(i.e., its environment, not the name of the style). If
"JSSextra" has not been created yet, it creates it first.
If argument style is used, as in
bibstyle_JSSextra("mystyle"), a style "mystyle" initially
equivalent to "JSSextra" is returned (it is created if
necessary). The returned environment can be amended to derive a new
bib style.
an environment
Georgi N. Boshnakov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.